"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styles = require("@material-ui/core/styles");

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var useStyles = (0, _styles.makeStyles)(function (theme) {
  return {
    root: {},
    primary: {},
    secondary: {
      '& > *': {
        display: 'inline-block'
      },
      '& > :not(:last-child)': {
        paddingRight: theme.spacing()
      },
      '@media print': {
        '& > a': {
          color: 'black',
          textDecoration: 'none'
        }
      }
    }
  };
});
/**
 * Util, string builder for USA formatted addresses from JSONResume
 * schema's basic.location specification.
 */

var Location = function Location(_ref) {
  var address = _ref.address,
      city = _ref.city,
      region = _ref.region,
      postalCode = _ref.postalCode,
      countryCode = _ref.countryCode;
  return /*#__PURE__*/_react.default.createElement("span", null, address, " ", city, " ", region, ", ", postalCode, " ", countryCode, ' ');
};

Location.propTypes = {
  address: _propTypes.default.string,
  city: _propTypes.default.string,
  region: _propTypes.default.string,
  postalCode: _propTypes.default.string,
  countryCode: _propTypes.default.string
};
Location.defaultProps = {
  address: '1 Main St',
  city: 'New York',
  region: 'NY',
  postalCode: '01234',
  countryCode: 'USA'
};
/**
 * Resume heading block, generated from the JSONResume schema's basic
 * (sub-object) specification.
 */

var Heading = function Heading(_ref2) {
  var name = _ref2.name,
      title = _ref2.title,
      email = _ref2.email,
      phone = _ref2.phone,
      location = _ref2.location,
      disableContact = _ref2.disableContact;
  var classes = useStyles();
  return /*#__PURE__*/_react.default.createElement("div", {
    className: classes.root
  }, /*#__PURE__*/_react.default.createElement(_Typography.default, {
    variant: "h5"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.primary
  }, /*#__PURE__*/_react.default.createElement("span", null, name, ", ", title))), !disableContact && /*#__PURE__*/_react.default.createElement(_Typography.default, {
    variant: "subtitle1"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.secondary
  }, phone && /*#__PURE__*/_react.default.createElement("a", {
    href: "tel:".concat(phone)
  }, phone, " "), email && /*#__PURE__*/_react.default.createElement("a", {
    href: "mailto:".concat(email, "?subject=Inquiry")
  }, email, " "), location.address && /*#__PURE__*/_react.default.createElement(Location, location))));
};

Heading.propTypes = {
  name: _propTypes.default.string,
  title: _propTypes.default.string,
  phone: _propTypes.default.string,
  email: _propTypes.default.string,
  location: _propTypes.default.shape(Location.propTypes),
  disableContact: _propTypes.default.bool
};
Heading.defaultProps = {
  name: '',
  title: '',
  phone: '',
  email: '',
  disableContact: false,
  location: Location.defaultProps
};
var _default = Heading;
exports.default = _default;