"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.compactList = exports.fixedColumn = exports.column = exports.row = void 0;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * CSS in JS styling (JSS).
 * Intended to be passed to Material UI  makeStyles hook.
 */

/**
 * A basic row container class,
 * children should use the column class to
 * build a row/column structure
 */
var row = function row(theme) {
  return _defineProperty({
    display: 'flex',
    flexDirection: 'row',
    flexWrap: 'wrap',
    width: '100%'
  }, theme.breakpoints.down('sm'), {
    '@media not print': {
      display: 'block'
    }
  });
};
/**
 * A column to place within a row
 */


exports.row = row;

var column = function column(theme) {
  return _defineProperty({
    display: 'flex',
    flexDirection: 'column',
    flex: 1
  }, theme.breakpoints.down('sm'), {
    '@media not print': {
      display: 'block'
    }
  });
};

exports.column = column;

var fixedColumn = function fixedColumn(size) {
  return {
    flexGrow: 0,
    flexShrink: 0,
    flexBasis: size
  };
};
/**
 * A space-saver, doesn't indent ul's children.
 * Buys some extra horizontal room in resume lists
 */


exports.fixedColumn = fixedColumn;

var compactList = function compactList(theme) {
  return _defineProperty({
    margin: '8px 0px',
    padding: '0px 0px 0px 16px'
  }, theme.breakpoints.down('sm'), {
    '@media not print': {
      '& > *': {
        margin: '8px 0px'
      }
    }
  });
};

exports.compactList = compactList;